Documentation
¶
Overview ¶
Package ynab implements the client API
Index ¶
Examples ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ClientServicer ¶
type ClientServicer interface {
User() *user.Service
Budget() *budget.Service
Account() *account.Service
Category() *category.Service
Payee() *payee.Service
Month() *month.Service
Transaction() *transaction.Service
RateLimit() *api.RateLimit
}
ClientServicer contract for a client service API
func NewClient ¶
func NewClient(accessToken string) ClientServicer
NewClient facilitates the creation of a new client instance
Example ¶
c := ynab.NewClient("<valid_ynab_access_token>")
c.User().GetUser() //nolint:errcheck
Directories
¶
| Path | Synopsis |
|---|---|
|
Package api implements shared structures and behaviours of the API services
|
Package api implements shared structures and behaviours of the API services |
|
account
Package account implements account entities and services
|
Package account implements account entities and services |
|
budget
Package budget implements budget entities and services
|
Package budget implements budget entities and services |
|
category
Package category implements category entities and services
|
Package category implements category entities and services |
|
month
Package month implements month entities and services
|
Package month implements month entities and services |
|
payee
Package payee implements payee entities and services
|
Package payee implements payee entities and services |
|
transaction
Package transaction implements transaction entities and services
|
Package transaction implements transaction entities and services |
|
user
Package user implements transaction user and services
|
Package user implements transaction user and services |
Click to show internal directories.
Click to hide internal directories.